@@ -20,12 +20,16 @@ end
 Wg=rand_orth(m);
 x=Wg*s;                      % rotates data to generate mixtures
 
+% ONE UNIT CONTRAST FUNCTION - HERMITE KERNEL  
+% Wcca=kernel_ica(x,'contrasttype','oneunit','ncomp',m,'contrast','kgv', ...
+%  'kernel','hermite','p',3, 'sig',1.5,'kap',.0001,'polish',1,'restarts',2);
 
-Wcca=kernel_ica(x,'contrast','kcca', ... 
+% ONE UNIT CONTRAST FUNCTION - HERMITE KERNEL  
+Wcca=kernel_ica(x,'ncomp',m,'contrast','kgv', ...
    'sig',1,'kap',.01,'polish',1,'restarts',2);
-sestimate=Wcca*x;
 
-% plot results
+
+sestimate=Wcca*x;
 
 for i=1:m
 subplot(3,m,i)
